CloseEvent

Struct CloseEvent 

pub struct CloseEvent {
Show 17 fields pub id: String, pub action_id: Option<String>, pub fill_id: Option<String>, pub position_id: String, pub symbol: String, pub side: Side, pub ts: NaiveDateTime, pub size: f64, pub price: f64, pub entry_price: Option<f64>, pub pnl: f64, pub commission: f64, pub native_pnl: Option<f64>, pub native_currency: Option<String>, pub pnl_conversion: Option<ConversionResult>, pub reason: CloseReason, pub remaining_size: Option<f64>,
}
A realized close, including partial closes, in additive account currency.

Fields

id: Stringaction_id: Option<String>fill_id: Option<String>position_id: Stringsymbol: Stringside: Sidets: NaiveDateTimesize: f64price: f64entry_price: Option<f64>

Remaining-inventory average cost used to realize this close.

pnl: f64

Realized profit and loss for this close, already net of commission.

commission: f64

Account-currency exit commission already subtracted from pnl.

native_pnl: Option<f64>native_currency: Option<String>pnl_conversion: Option<ConversionResult>reason: CloseReasonremaining_size: Option<f64>

Remaining size after this close when known.

Implementations

Source

impl CloseEvent

pub fn new( position_id: impl Into<String>, sequence: u64, symbol: impl Into<String>, side: Side, ts: NaiveDateTime, size: f64, price: f64, pnl: f64, reason: CloseReason, ) -> Self