pub struct MarketEntrySizingAudit {Show 14 fields
pub action_id: String,
pub trade_id: Option<String>,
pub configured_basis: MarketEntrySizingBasis,
pub applied_basis: MarketEntrySizingBasis,
pub fallback_to_fill: bool,
pub original_signal_price: Option<f64>,
pub sizing_reference_price: f64,
pub execution_price: f64,
pub protective_stop: Option<f64>,
pub requested_account_risk: Option<f64>,
pub native_loss_per_lot: Option<f64>,
pub account_loss_per_lot: Option<f64>,
pub final_lot: f64,
pub levels_crossed_at_fill: Vec<String>,
}Expand description
Sizing inputs and outputs recorded for one successfully executed market entry.
Fields
action_id: Stringtrade_id: Option<String>configured_basis: MarketEntrySizingBasisapplied_basis: MarketEntrySizingBasisfallback_to_fill: booloriginal_signal_price: Option<f64>sizing_reference_price: f64execution_price: f64protective_stop: Option<f64>requested_account_risk: Option<f64>native_loss_per_lot: Option<f64>account_loss_per_lot: Option<f64>final_lot: f64levels_crossed_at_fill: Vec<String>Signal levels already crossed by the execution price at fill time. Empty when every attached level was on its protective side.