pub struct EventMetadata {
pub roles: SeriesRoles,
pub series_rank: u32,
pub row_sequence: u64,
}Expand description
Deterministic identity and ordering metadata for one market event.
Fields
roles: SeriesRolesseries_rank: u32row_sequence: u64Physical source-row ordinal when supplied by a streaming source, otherwise the emitted event ordinal.
Implementations
Sourceimpl EventMetadata
impl EventMetadata
pub const fn new( roles: SeriesRoles, series_rank: u32, row_sequence: u64, ) -> Self