pub struct IntrinsicRobustnessSection {
pub best_one_removed: MetricValue<RemovalImpact>,
pub best_five_percent_removed: MetricValue<RemovalImpact>,
pub best_one_positive_concentration: MetricValue<f64>,
pub best_five_percent_positive_concentration: MetricValue<f64>,
pub pnl_concentration: PnlConcentrationSection,
pub rolling_outcomes: RollingOutcomes,
}Fields
best_one_removed: MetricValue<RemovalImpact>best_five_percent_removed: MetricValue<RemovalImpact>best_one_positive_concentration: MetricValue<f64>Share of gross positive outcome contributed by the best position.
best_five_percent_positive_concentration: MetricValue<f64>Share of gross positive outcome contributed by the best 5% of positions.
pnl_concentration: PnlConcentrationSectionFixed-count concentration complements the sample-size-relative 5% metric.
rolling_outcomes: RollingOutcomesTrait Implementations
Sourceimpl Clone for IntrinsicRobustnessSection
impl Clone for IntrinsicRobustnessSection
Sourcefn clone(&self) -> IntrinsicRobustnessSection
fn clone(&self) -> IntrinsicRobustnessSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntrinsicRobustnessSection
impl Debug for IntrinsicRobustnessSection
Sourceimpl<'de> Deserialize<'de> for IntrinsicRobustnessSection
impl<'de> Deserialize<'de> for IntrinsicRobustnessSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for IntrinsicRobustnessSection