pub struct ActionDisposition {
pub action_id: String,
pub action_kind: Option<String>,
pub signal_ts: Option<NaiveDateTime>,
pub effective_ts: Option<NaiveDateTime>,
pub status: ActionDispositionStatus,
pub reason: Option<String>,
pub position_ids: Vec<String>,
}Expand description
Exactly one terminal accounting record for one runner action.
Fields
action_id: Stringaction_kind: Option<String>Stable caller-defined action category (for example, open or close).
signal_ts: Option<NaiveDateTime>effective_ts: Option<NaiveDateTime>status: ActionDispositionStatusreason: Option<String>Machine-stable or human-readable reason. Usually absent for Applied.
position_ids: Vec<String>Position ids affected by bulk actions are retained in deterministic order.
Implementations
Sourceimpl ActionDisposition
impl ActionDisposition
pub fn new( action_id: impl Into<String>, status: ActionDispositionStatus, ) -> Self
pub fn applied(action_id: impl Into<String>) -> Self
pub fn skipped(action_id: impl Into<String>, reason: impl Into<String>) -> Self
pub fn rejected(action_id: impl Into<String>, reason: impl Into<String>) -> Self
pub fn failed(action_id: impl Into<String>, reason: impl Into<String>) -> Self
Sourcepub const fn is_terminal(&self) -> bool
pub const fn is_terminal(&self) -> bool
All statuses represented by this type are terminal by construction.