pub struct ProfileRegistry { /* private fields */ }Expand description
A collection of named management profiles loaded from TOML.
Implementations
Sourceimpl ProfileRegistry
impl ProfileRegistry
Sourcepub fn load(path: impl AsRef<Path>) -> Result<Self, ProfileError>
pub fn load(path: impl AsRef<Path>) -> Result<Self, ProfileError>
Load profiles from a TOML file.
Sourcepub fn from_toml(content: &str) -> Result<Self, ProfileError>
pub fn from_toml(content: &str) -> Result<Self, ProfileError>
Load profiles from a TOML string.
Sourcepub fn get(&self, name: &str) -> Option<&ManagementProfile>
pub fn get(&self, name: &str) -> Option<&ManagementProfile>
Get a profile by name.
Sourcepub fn validate_profile(p: &ManagementProfile) -> Result<(), ProfileError>
pub fn validate_profile(p: &ManagementProfile) -> Result<(), ProfileError>
Validate a single profile’s configuration (public static method).
Sourcepub fn insert(
&mut self,
profile: ManagementProfile,
overwrite: bool,
) -> Result<(), ProfileError>
pub fn insert( &mut self, profile: ManagementProfile, overwrite: bool, ) -> Result<(), ProfileError>
Insert a profile into the registry. If overwrite is false, returns
an error when a profile with the same name already exists.