Module context

Module context 

Read-only historical and engine state exposed at one strategy boundary.

Structs

StrategyContext
Complete causal state available while evaluating one historical boundary.